%%DATA_FOR_FULL_UNCERT_10p
%%			This program was used to generate the values of parameters used in MULTISITE_FULL_UNC_10pop.m
%%			MULTISITE_FULL_UNC_10pop.m corresponds to the constrained scenario used for the viability assessment under full uncertainty (10 local populations) in the manuscript
%%			ANTONIO HERNNDEZ-MATAS, JOAN REAL, MARCOS MOLEN, LUIS PALMA, JOSE ANTONIO SNCHEZ-ZAPATA, ROGER PRADEL, MARTINA CARRETE, JOSE MARA GIL-SNCHEZ,PEDRO BEJA, JAVIER BALBONTN, NICOLAS VINCENT-MARTIN, ALAIN RAVAYROL, JOSE RAMN BENTEZ, BERNARDO ARROYO, CARMELO FERNNDEZ, ERNESTO FERREIRO, JAVIER GARCA
%%			From local monitoring to a broad-scale viability assessment: a case study for the endangered Bonelli's eagle Aquila fasciata in Western Europe 
%%			Ecological Monographs, In Press
%%			 
%%			The program allows to incorporate the effect of environmental and sample variance in adult survival and adult fertility
%%			Non-adult survival only incorporated sample variance
%%			
%%			NOTE: the code was written by Antonio Hernndez-Matas  

clear; clear global; rand('state',sum(101*clock)); close all;
dbstop if error


%define some global parameters
NumPop=10;
ageclass=6;

%Vital rates that are shared by all local populations
Sr=0.5; %Sex-ratio
RB= [0.16076 0.67967 0.93419 1]; %ratio of territorials: expected ratio of territorial birds in any given age class from 2 year-old to 5 year-old and older birds (these probabilities apply in t)
RR = [0.160762598	0.618313085	0.794574005	1]; %recruitment rate: probability that a non-territorial bird of any given age will try to settle as territorial (these probabilities apply in the time step from t-1 to t)
%This measurements of recruitment are based in the calculations from Hernndez-Matas et al. 2010. Determinants of Territorial Recruitment in Bonellis Eagle (Aquila fasciata) Populations. Auk 127:173184. 
%and the transformations developed by Pradel and Lebreton. 1999. Comparison of different approaches to the study of local recruitment of breeders. Bird Study 46:7481

%carrying capacity
K=[52	116	68	365	103	85	36	42	95	140]; 

%dispersals probabilities, rows are local populations of origin and columns are destination local population, the diagonal is the probability of non dispersal
%%POWER LAW, AVERAGE
DISP=[0.6059	0.2257	0.0187	0.0196	0.0409	0.0598	0.0035	0.0013	0.0046	0.02	;
0.0143	0.5319	0.0052	0.1088	0.1397	0.1114	0.0068	0.0173	0.0092	0.0553	;
0.007	0.0257	0.6098	0.036	0.0055	0.006	0.0021	0.0013	0.0734	0.2331	;
0.0015	0.0373	0.0048	0.7553	0.0357	0.0128	0.0045	0.025	0.0315	0.0916	;
0.006	0.1297	0.0029	0.1075	0.5764	0.1049	0.0044	0.0303	0.0076	0.0303	;
0.012	0.1452	0.0019	0.0217	0.1693	0.5875	0.0411	0.0066	0.0049	0.0097	;
0.0014	0.012	0.0015	0.0166	0.0092	0.2093	0.7385	0.0011	0.0039	0.0066	;
0.0014	0.0666	0.0034	0.4103	0.0923	0.0163	0.0041	0.3555	0.0088	0.0414	;
0.0009	0.0078	0.016	0.1343	0.0073	0.008	0.0028	0.0017	0.6464	0.1748	;
0.0019	0.0335	0.026	0.1922	0.0216	0.0146	0.0051	0.0056	0.0894	0.6103	];
     
%%some related matrix useful when modeling the dispersal process
ATR=DISP;
%%ATR2 is useful for dispersers only
ATR2=ATR;
for i=1:NumPop  
   if (ATR(i,i)==1)
      ATR2(i,:)=zeros(1,NumPop);
   else
      ATR2(i,i)=0; 
   	ATR2(i,:)=ATR2(i,:)/sum(ATR2(i,:)); end;
end;

%%%Set the values of vital rates
%non adult survivals: there are two groups: b: southern populations and a: rest of populations
S1a_mean=0.480265629; %first-year survival for the rest of populations
S1a_var=0.004160555; %sample variance
S1a=[];
   for fx99 = 1:99
	valaux=betaval(S1a_mean,sqrt(S1a_var),rand);
   S1a(fx99)=valaux; %S1a(NP,fx99)=valaux;
S1a=sort(S1a)';
end;

S1b_mean=0.662946429; %first-year survival in southern populations
S1b_var=0.013067084; %sample variance
S1b=[];
   for fx99 = 1:99
	valaux=betaval(S1b_mean,sqrt(S1b_var),rand);
   S1b(fx99)=valaux;
S1b=sort(S1b)';
end;

S23a_mean=0.573883442; %second- and third-year survival in the rest of populations
S23a_var=0.003035256; %sample variance
S23a=[];
   for fx99 = 1:99
	valaux=betaval(S23a_mean,sqrt(S23a_var),rand);
   S23a(fx99)=valaux;
S23a=sort(S23a);
end;

S23b_mean=0.719975512;  %second- and third-year survival in southern populations
S23b_var=0.018839238; %sample variance
S23b=[];
   for fx99 = 1:99
	valaux=betaval(S23b_mean,sqrt(S23b_var),rand);
   S23b(fx99)=valaux;
S23b=sort(S23b)';
end;

%initially considered non-adult survivals
S=[0.4803	0.5739	0.5739	0.8522	;
0.4803	0.5739	0.5739	0.8474	;
0.4803	0.5739	0.5739	0.8239	;
0.6629	0.7200	0.7200	0.8688	;
0.4803	0.5739	0.5739	0.8100	;
0.4803	0.5739	0.5739	0.8296	;
0.4803	0.5739	0.5739	0.8212	;
0.4803	0.5739	0.5739	0.8294	;
0.6629	0.7200	0.7200	0.8748	;
0.4803	0.5739	0.5739	0.8619]	;

%adult survival
SAmean=[0.913867922	0.907896531	0.882908039	0.925755536	0.867991242	0.889065693	0.879978186	0.892729015	0.937492268	0.923638943]; %% best estimates of adult survivals
SAvar_env=[0.002595742	0.000693942	0.0030304	0.000655006	0.003180415	0.001281247	0.002070305	0.001656961	0.000555761	0.000622246]; %%environmental variance
SAvar_par=[0.000267178	0.000198492	0.000918774	6.4661E-05	0.000138742	9.22609E-05	5.10125E-05	0.000413367	8.63177E-05	0.000133066]; %sample variance

SA_par=[]; %generates a matrix in which each row contains the possible values that may take adult survival based in the estimated sample variance
for NP=1:NumPop
   for fx99 = 1:99
	valaux=betaval(SAmean(NP),sqrt(SAvar_par(NP)),rand);
   SA_par(NP,fx99)=valaux;
end;
SA_par=sort(SA_par')';
end;

SA_global=[]; %%generates an array that for each population (third index) contains a matrix where each row contains the values of
%%survival based in environmental variance that adult survival may take for any given value of survival based in sample variance
for uu=1:length(SA_par)
   for NP=1:NumPop
      disp([uu NP]);
   for fx99 = 1:99
	valaux=betaval(SA_par(NP,uu),sqrt(SAvar_env(NP)),rand);
   SA_global(uu,fx99,NP)=valaux;
end;
SA_global(uu,:,NP)=sort(SA_global(uu,:,NP)');
end;
end; %ends for uu
   
%non-adult fertilities
 FNA=[0.00000000	0.00000000;
0.28571429	0.30769231;
0.00000000	0.00000000;
0.28571429	0.61470588;
0.28571429	0.80000000;
0.28571429	0.40000000;
0.45388889	0.45388889;
0.28571429	0.51041667;
0.28571429	0.50000000;
0.28571429	0.33333333];

%adult fertilities
FAmean=[0.731309765	0.8842485	0.604900962	1.231149291	1.046406422	1.129109343	0.978656511	1.201271966	0.830328235	0.93572236];
FAvar_env=[0.05465705	0.052814006	0.065473557	0.041248755	0.064705219	0.02451698	0.045392109	0.060759509	0.032828738	0.05510211];
FAvar_par=[0.026272726	0.026303319	0.032900759	0.019384434	0.035782899	0.037317978	0.0369276	0.035444552	0.038338872	0.03826215]; %varincia en precisi parmetre
FA_par=[]; %generates a matrix in which each row contains the possible values that may take adult fertility based in the estimated sample variance
for NP=1:NumPop
   for fx99 = 1:99
   valaux=stretchbetaval(FAmean(NP),sqrt(FAvar_par(NP)),0,2,rand);
   FA_par(NP,fx99)=valaux;
end;
FA_par=sort(FA_par')';
end;

FA_global=[]; %%generates an array that for each population (third index) contains a matrix where each row contains the values of
%%fertility based in environmental variance that adult fertility may take for any given value of fertility based in sample variance
for uu=1:length(FA_par)
   for NP=1:NumPop
      disp([uu NP]);
   for fx99 = 1:99
      valaux=stretchbetaval(FA_par(NP,uu),sqrt(FAvar_env(NP)),0,2,rand);
      FA_global(uu,fx99,NP)=valaux;
end;
FA_global(uu,:,NP)=sort(FA_global(uu,:,NP)');
end;
end; %ends for uu

ratios_no_pb=[0.5008    0.1449    0.0301         0;  %this matrix is only used in t==1 to correct for the number of non-territorial birds (values estimated from the results of 18 population models)    
    0.9983    0.8178    0.2697         0;
    0.5904    0.1960    0.0398         0;
    0.8623    0.3654    0.0826         0;
    0.9945    0.7874    0.2504         0;
    0.9950    0.7296    0.2063         0;
    0.7813    0.3088    0.0630         0;
    0.9628    0.5275    0.1214         0;
    0.8176    0.2952    0.0608         0;
    0.7850    0.2433    0.0584         0];


%%initial population sizes are based in the 2005 censuses, the stable age distribution and the expected number of non-territorial birds of territorial ages
n0=[5	3	3	2	2	10; 
39	19	13	8	7	73;
9	5	3	3	3	26;
352	218	146	99	89	447;
48	24	16	10	9	76;
35	18	11	6	5	54;
14	7	4	3	3	23;
13	7	4	3	3	17;
33	21	15	11	10	62;
60	29	17	10	9	115];


save PAR_FULL_UNC NumPop ageclass Sr RB RR K DISP ATR ATR2 S1a S1b S23a S23b S SA_global FNA FA_global ratios_no_pb n0
