%%%LIKELIHOOD_ESTIMATION
%%			This program was used for model choice to evaluate uncertainty in the model structure and 
%%			in the natal dispersal kernel  in:
%%			
%%			ANTONIO HERNNDEZ-MATAS, JOAN REAL, MARCOS MOLEN, LUIS PALMA, JOSE ANTONIO SNCHEZ-ZAPATA, ROGER PRADEL, MARTINA CARRETE, JOSE MARA GIL-SNCHEZ,PEDRO BEJA, JAVIER BALBONTN, NICOLAS VINCENT-MARTIN, ALAIN RAVAYROL, JOSE RAMN BENTEZ, BERNARDO ARROYO, CARMELO FERNNDEZ, ERNESTO FERREIRO, JAVIER GARCA
%%			From local monitoring to a broad-scale viability assessment: a case study for the endangered Bonelli's eagle Aquila fasciata in Western Europe 
%%			Ecological Monographs, In Press
%%			
%%			The program requires a three-dimensional array with the following structure: lambdas_scenario(numreps,NumPop,nscenarios);
%%			that is, each lambdas_scenario(:,:,nscenarios) stores the obtained lambdas for each replicate (rows) and local population (columns);
%%			it is also required that the values of lambda are sorted in ascendent order within each local population and scenario.
%%			The approach to model choice relies on how likely the observed lambdas are given each model's set of predictions. For each model and for 
%%			each population with an observed lambda, we binned the simulated lambda values for that population using fairly fine bins (0.01 bins). 
%%			Then, we obtained the probability of the simulated lambdas being within each bin as a means of estimating the probability of 
%%			seeing the observed lambda for that population, P(LAMBDA(i)). Finally, we obtained the log-likelihood of the observed lambdas for each model 
%%			as the sum of ln(P(LAMBDA(i))). Models were chosen by comparing the negative log likelihoods for each considered model (Hilborn & Mangel 1997).
%%			
%%			NOTE: the code was written by Antonio Hernndez-Matas and it was developed after review comments 
%%			by Elizabeth Crone, and the method was proposed by Daniel Doak. 


clear; clear global; rand('state',sum(101*clock)); close all;
dbstop if error

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load LAMBDAS_SUMMARY 


%%Some initial parameters
NumPop=12; %number of monitored populations for which we know the observed lambda
numreps=10000; %n replicates
nscenarios=10; %n scenarios considered

bin_w=0.01; %bin width
bin_summary(:,2)=linspace(0.5,1.49)'; %creates a matrix where the second column is the values of lambda %%check that the distance between two values of the vector is equal to bin width
bin_summary(:,1)=[1:100]';


%%Observed lambdas in the local populations
obs_lambdas=[0.969152234	0.97403282	0.964713868	0.925874712	1.004890938	1	0.984921375	1	1.016163504	0.969522147	1.003106148	1.038093444];

%%creates a vector containing the values of "bin positions" of the observed lambdas
for z=1:NumPop
   obs_loc_bin(z)=min(find(obs_lambdas(z)<bin_summary(:,2)));
end;
obs_loc_bin=obs_loc_bin - 1; 

%%estimates the probabilities of getting simulated lambdas within the bin where the observed lambda is placed
for i=1:nscenarios
   for z=1:NumPop
      obs_loc=obs_loc_bin(z);
      prob_obs_pop(z,i)=((sum((lambdas_scenario(:,z,i)>=bin_summary(obs_loc,2)) & (lambdas_scenario(:,z,i)<bin_summary(obs_loc+1,2))))/numreps);
   end;
end;

%%%in those populations where the probabilities are 0, we set a value equal to the inverse of the number of replicates
prob_obs_pop(find(prob_obs_pop==0))=1/numreps;

%%estimate log likelihood for each scenario
for i=1:nscenarios
   log_likelihood_summ(i)=sum(log(prob_obs_pop(:,i)));
   prob_obs_summ(i)=sum(prob_obs_pop(:,i));
end;
prob_obs_summ=prob_obs_summ./NumPop;
deviance_summ=-2.*log_likelihood_summ;

%save LOGLIKELIHOOD_RESULTS prob_obs_pop prob_obs_summ log_likelihood_summ deviance_summ
%%log_likelihood_summ contains the likelihood estimation for each scenario

