%%MULTISITE_PARAM_UNC_10pop
%%			This program  corresponds to the constrained scenario used for the viability assessment under full parameter uncertainty (10 local populations) in the manuscript
%%			ANTONIO HERNNDEZ-MATAS, JOAN REAL, MARCOS MOLEN, LUIS PALMA, JOSE ANTONIO SNCHEZ-ZAPATA, ROGER PRADEL, MARTINA CARRETE, JOSE MARA GIL-SNCHEZ,PEDRO BEJA, JAVIER BALBONTN, NICOLAS VINCENT-MARTIN, ALAIN RAVAYROL, JOSE RAMN BENTEZ, BERNARDO ARROYO, CARMELO FERNNDEZ, ERNESTO FERREIRO, JAVIER GARCA
%%			From local monitoring to a broad-scale viability assessment: a case study for the endangered Bonelli's eagle Aquila fasciata in Western Europe 
%%			Ecological Monographs, In Press
%%			 
%%			The simulation is the same that in MULTISITE_CONS_10pop, with some small variations to account for parameter uncertainty;
%%			and therefore, only those parts that are different are commented.
%%			
%%			NOTE: the code was written by Antonio Hernndez-Matas  

clear; clear global; rand('state',sum(101*clock)); close all;
dbstop if error

load PAR_FULL_UNC

%define some global parameters
Nx=50;           % quasi-extinction threshold
tmax=50;        % time horizon
numreps=10000;   % no. of replicates for prob.(ext.) calculation


%%%%%******************************************************************************
%%%%%******************************************************************************
%%%%%******************************************************************************
%%code of the simulation
rand('state',sum(100*clock)); % seed random number generator

Ns=zeros(1,numreps);
No_breed=zeros(1,numreps);
Nt=zeros(1,numreps);

for rep=1:numreps	
      disp(rep);
      n=n0;		
      
%%builds the matrices of vital rate data to be used in each replicate
rnd1=round((rand*98)+1);
S_low=[S1a(rnd1) S23a(rnd1) S23a(rnd1)]; 
S_hig=[S1b(rnd1) S23b(rnd1) S23b(rnd1)];
S=[S_low;S_low;S_low;S_hig;S_low;S_low;S_low;S_low;S_hig;S_low]; %it still lacks the fourth column

SA=[];
for i=1:NumPop %takes a value of adult survival for each population      
   SA(i,:)=SA_global(rnd1,:,i);
end;

rtS4=0.821163142/0.879978187; %construct fourth-year survival (fourth column of S)
S4_aux=mean(SA').*rtS4;
S(:,4)=S4_aux';

rnd2=round((rand*98)+1);
FA=[];
for i=1:NumPop %takes a value of adult fertility for each population      
   FA(i,:)=FA_global(rnd2,:,i);
end;

%%begins loop for each year cycle           
for t=1:tmax	% for each year,

if t==1; 
   nb=zeros(NumPop,4);
   for i=1:NumPop 
      pb_aux(i,:)=round(n(i,3:6).*RB);
      for bckw=0:3
         K_aux=K(i)-sum(nb(i,:));
         pos=4-bckw;
         if(pb_aux(i,pos) <= K_aux) nb(i,pos)=pb_aux(i,pos);
         else nb(i,pos) = K_aux; end;
         if sum(nb(i,:))>=K(i) break;end;
      end;
   end;
   no_pb_t0_aux=n(:,3:6)-nb; 						
   no_pb_t0=floor(no_pb_t0_aux.*ratios_no_pb);
   pb_no_bre_t0=n(:,3:6)-nb-no_pb_t0;
end; %ends if

for i=1:NumPop 
for j=1:2
   nnb1(i,j+1)=sum(rand(1,nb(i,j))<S(i,j+2));
end;
	SA_aux(i)=SA(i,round((rand*98)+1));
   ad1_nnb(i)=sum(rand(1,nb(i,3))<SA_aux(i)); 
   ad2_nnb(i)=sum(rand(1,nb(i,4))<SA_aux(i)); 
	nnb1(i,4)=ad1_nnb(i)+ad2_nnb(i);   
end;

for i=1:NumPop 
for j=1:2
   no_nnb1(i,j+1)=sum(rand(1,no_pb_t0(i,j))<S(i,j+2));
end;
   ad1_no_nnb(i)=sum(rand(1,no_pb_t0(i,3))<SA_aux(i));
   ad2_no_nnb(i)=sum(rand(1,no_pb_t0(i,4))<SA_aux(i)); 
	no_nnb1(i,4)=ad1_no_nnb(i)+ad2_no_nnb(i);   
end;

if (t>1)
for i=1:NumPop 
for j=1:2 
   pb_no_bre(i,j+1)=sum(rand(1,pb_no_bre_t0(i,j))<S(i,j+2));
end;
   ad1_pb_no_bre(i)=sum(rand(1,pb_no_bre_t0(i,3))<SA_aux(i)); 
   ad2_pb_no_bre(i)=sum(rand(1,pb_no_bre_t0(i,4))<SA_aux(i)); 
	pb_no_bre(i,4)=ad1_pb_no_bre(i)+ad2_pb_no_bre(i);   
end;
else 
  pb_no_bre=zeros(NumPop,4);
end; 

for i=1:NumPop 
   for j=2:3
   nn(i,j)=sum(rand(1,n(i,j-1))<S(i,j-1));
end;
end;

for i=1:NumPop 
   no_nnb1(i,1)=nn(i,3);
end;

aval_abs=(K-sum(nnb1'));
aval_abs(find(aval_abs<0))=0;

for i=1:NumPop 
   for y=1:4 
   pb(i,y)=sum(rand(1,no_nnb1(i,y))<RR(y));
end;
   no_pb(i,:)=no_nnb1(i,:)-pb(i,:); 
end;

for i=1:NumPop
   for y=1:4
         pr(i,y)=sum(rand(1,pb(i,y))<ATR(i,i));
end;
end;

for i=1:NumPop
   for bckw=0:3
      pos=4-bckw;
      if pb_no_bre(i,pos)<aval_abs(i);  
         aval_abs(i) =aval_abs(i)-pb_no_bre(i,pos); 
         pb_exp(i,pos)=pb_no_bre(i,pos); 
         pb_no_bre(i,pos)=0; 
      else
         pb_exp(i,pos)=aval_abs(i);
         pb_no_bre(i,pos)=(pb_no_bre(i,pos)-aval_abs(i)); 
         aval_abs(i)=0;
      end;
   end;
end; 

for i=1:NumPop
   for bckw=0:3 
      pos=4-bckw;
      if pr(i,pos)<aval_abs(i);
         aval_abs(i) =aval_abs(i)-pr(i,pos);
         pd(i,pos)=pb(i,pos)-pr(i,pos); 
         pb_no_bre(i,pos)=pb_no_bre(i,pos);
      else
         pb_no_bre(i,pos)=pb_no_bre(i,pos)+(pr(i,pos)-aval_abs(i));   
         pd(i,pos)=pb(i,pos)-pr(i,pos); 
         pr(i,pos)=aval_abs(i);
         aval_abs(i)=0;
      end;
   end;
end;

pin=zeros(NumPop,4);
for i=1:NumPop 
   if ATR(i,i)<1 
      ATR_aux=ATR2(i,:);
      ATR_aux(i)=[]; 
      roulette = cumsum(ATR_aux); 
      terr_age=1:4;
      back_age=terr_age(length(terr_age):-1:1);
      for y=back_age
         v_pin_aux=zeros(1,NumPop-1); 
         for ii=1:pd(i,y) 
            rnd_num=rand;
            if (rnd_num>0.99) rnd_num=0.99; end; 
            pop_dest = find( rnd_num <= roulette );
            pop_dest = pop_dest(1);   
            v_pin_aux(pop_dest)=v_pin_aux(pop_dest)+1;
         end;
         if (i==1)
         	v_pin_aux=[0,v_pin_aux];
      	else
            v_pin_aux=[v_pin_aux(1:(i-1)),0,v_pin_aux(i:end)]; 
         end;
         
         for j=1:NumPop 
            if v_pin_aux(j)<aval_abs(j);
               pin(j,y)=pin(j,y)+v_pin_aux(j);
               aval_abs(j) =aval_abs(j)-v_pin_aux(j);
               pd(i,y)=pd(i,y)-v_pin_aux(j);
            else
               pin(j,y)=pin(j,y)+aval_abs(j); 
               pd(i,y)=pd(i,y)-aval_abs(j);
               pb_no_bre(j,y)=pb_no_bre(j,y)+(v_pin_aux(j)-aval_abs(j)); 
               aval_abs(j)=0;
            end;
         end; 
      end;
   end;
end; %ends population of origin  

pb2=pr+pin+pb_exp;
new_nn=nnb1+pb2+no_pb+pb_no_bre;
nn(:,3:ageclass)=new_nn;
nnb=nnb1+pb2; 
no_nnb=nn(:,3:6)-nnb;

for i=1:NumPop
   nn(i,1)=round((nnb(i,1)*(FNA(i,1)*Sr))+(nnb(i,2)*(FNA(i,2)*Sr))+(nnb(i,3)*(FA(i,round((rand*98)+1))*Sr))+(nnb(i,4)*(FA(i,round((rand*98)+1))*Sr)));
end;

Npairs=sum(sum(nnb)); 
Npairs_pop=sum(nnb');
N=sum(sum(nn));
Nnonbre=N-Npairs;	

pop_fate(t,rep)=Npairs;
for i=1:NumPop 
   pop_fate_pops(t,rep,i)=Npairs_pop(i);
end;
if Npairs<=Nx break; end;

nb=nnb;
no_nb=no_nnb;
n=nn;
pb_no_bre_t0=pb_no_bre; 
no_pb_t0=no_pb;	

nn=[];
nnb=[];
no_nnb=[];
nnb1=[];
no_nnb1=[];
pb=[];
no_pb=[];
pr=[];
pd=[];
pin=[];
pb_no_bre=[];
pb_exp=[];

end; % for t

Ns(rep)=Npairs;
No_breed(rep)=Nnonbre;
Nt(rep)=N;
        
end; % for rep


%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%ENDS SIMULATION


%%%Some summary data

 %%Get average population fate 
 inv_pop_fate=sort(pop_fate');
 mean_pop_fate=[];
 mean_pop_fate(1,:)=inv_pop_fate(round((numreps/100)*2.5),:);
 mean_pop_fate(2,:)=mean(inv_pop_fate);
 mean_pop_fate(3,:)=inv_pop_fate(round((numreps/100)*97.5),:);

 %%%Estimate local population lambdas; only considers the period before extinction, irrespectively if after the population is recolonized
  lambdas_pop=zeros(NumPop,4);
    for i=1:NumPop
	ld_aux1 =zeros(1,numreps); %recipient for lambdas
	size_aux=size(pop_fate_pops(:,:,i));  %auxiliar vector for local population fates
		for z=1:size_aux(2)
   	vaux=pop_fate_pops(:,z,i)'; %another auxiliar recipient for local population fates
   	if sum(vaux==0)>0 %if extincition is done, then only consider the period before extinction
      vaux2=vaux(1:min(find(vaux==0)))+1; 
   	else
      vaux2=vaux;
   	end;
   	l_vaux=length(vaux2);
      	for q=1:(l_vaux-1)
          ld_aux2(q)=vaux2(q+1)./vaux2(q); %save lambdas for one year intervals in recipient 2
    		end;
    	ld_aux1(z)=gmean(ld_aux2); %geometric mean of lambdas (for each replicate)
    	ld_aux2=[]; %reset recipient 2
 		end;
   ld_aux1=sort(ld_aux1); %sort the vector with the values of lambdas for each replicate
          
 lambda=mean(ld_aux1); %mean lambda
 ic95_inf=ld_aux1(round((numreps/100)*2.5)); %95% percetile range
 ic95_sup=ld_aux1(round((numreps/100)*97.5));
 lambda_median=median(ld_aux1); %median
 
 lambdas_pop(i,1)=lambda; %records lambda summaries
 lambdas_pop(i,2)=ic95_inf;
 lambdas_pop(i,3)=ic95_sup;
 lambdas_pop(i,4)=lambda_median;
 end; %ends initial for

%%%Estimate overall population lambda
ld_aux1 =zeros(1,numreps); %recipient for lambdas
size_aux=size(pop_fate);
   for z=1:size_aux(2)
      for q=1:(size_aux(1)-1)
          if pop_fate(q+1,z)>=Nx
          ld_aux2(q)=pop_fate(q+1,z)./pop_fate(q,z); %save lambdas for one year intervals in recipient 2
          end;
    end;
    ld_aux1(z)=gmean(ld_aux2);
    ld_aux2=[]; %reset recipient 2
 end;
    ld_aux1=sort(ld_aux1);
 
 lambda=mean(ld_aux1);
 ic95_inf=ld_aux1(round((numreps/100)*2.5));
 ic95_sup=ld_aux1(round((numreps/100)*97.5));
 disp('lambda')
 disp(lambda)
 disp('lower 95CI')
 disp(ic95_inf)
 disp('upper 95CI')
 disp(ic95_sup)
 

%%%%SAVE MAIN RESULTS 
save MET10_PARAM_UNC pop_fate mean_pop_fate  pop_fate_pops lambda ic95_inf ic95_sup lambdas_pop


%%%%And some additional info about porbabilities of decline for local populations
n_pop_2005=[13	85	31	334	93	65	28	22	68	127];

thresh25 = floor(n_pop_2005.*0.75);
thresh50 = floor(n_pop_2005.*0.5);
thresh80 = floor(n_pop_2005.*0.2);


for ii=1:10
   for i=1:tmax	
   reduc25_unc(ii,i) =sum(pop_fate_pops(i,:,ii)<=thresh25(ii))/numreps; % Calculate the probability of decline of local populations to 75% of their initial size
   reduc50_unc(ii,i) =sum(pop_fate_pops(i,:,ii)<=thresh50(ii))/numreps; % Calculate the probability of decline of local populations to 50% of their initial size
   reduc80_unc(ii,i) =sum(pop_fate_pops(i,:,ii)<=thresh80(ii))/numreps; % Calculate the probability of decline of local populations to 20% of their initial size
end;
end;
   
save EXT_VAL_UNC reduc25_unc reduc50_unc reduc80_unc
